@@ -113,7 +113,7 @@ class Listpg:
 
     
     async def remove(self, **opt):
-        one_column = f"{list(opt.keys())[0]} = array_remove({list(opt.keys()[0])}, $1)"
+        one_column = f"{list(opt.keys())[0]} = array_remove({list(opt.keys())[0]}, $1)"
         enums = enumerate(opt.keys(), 2)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums)
 
